pub enum GitRepositorySelection {
Worktree {
root: PathBuf,
role: GitWorktreeRole,
administrative_directory: PathBuf,
},
CommonManager {
source_selection: GitManagerSourceSelection,
},
}Expand description
Selection made from the supplied path.
Variants
Worktree
The supplied path was inside one exact checked-out worktree.
Fields

role: GitWorktreeRoleStructural role of the selected worktree.
CommonManager
The supplied path addressed the common control directory instead of source.
Fields

source_selection: GitManagerSourceSelectionWhether the structurally active inventory permits automatic source selection.